
Overview
===========


:Title: Prostate Cancer
:Nickname: D9dot5C2
:Summary: 
:SubChallenges:
:Synapse page: https://www.synapse.org/#!Synapse:syn2813558


.. contents::


Scoring
---------

::

    from dreamtools import D9dot5C2
    s = D9dot5C2()
    filename = s.download_template()
    s.score(filename)


